.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Suitcase Documentation
======================

Suitcase translates documents generated by bluesky (or anything that follows
its "event model" schema) into file formats. This documentation contains a
:doc:`list of formats and layouts that are currently supported or in progress <formats>`.
It also provides :doc:`instructions for writing a suitcase for a new format <writing>`.

To install suitcase and start exporting data, see :doc:`usage`.

While most users will use suitcase to write files to disk, advanced users may
write to a memory buffer, a network socket, etc. The serialization
(documents-to-bytes) is separated from the transport (what to do with the
bytes).

.. toctree::
   :maxdepth: 2

   usage
   formats
   writing
